<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="mobile-web-app-capable" content="yes">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="<%= description_for(current_page) %>">

    <link rel="apple-touch-icon" sizes="180x180" href="<%= image_path("favicons/apple-touch-icon.png") %>">
    <link rel="icon" type="image/png" href="<%= image_path("favicons/favicon-32x32.png") %>" sizes="32x32">
    <link rel="icon" type="image/png" href="<%= image_path("favicons/favicon-16x16.png") %>" sizes="16x16">
    <link rel="manifest" href="/android-manifest.json">
    <link rel="mask-icon" href="<%= image_path("favicons/safari-pinned-tab.svg") %>" color="#5bbad5">
    <meta name="msapplication-config" content="/microsoft-tile.xml" />
    <meta name="theme-color" content="#ffffff">

    <meta name="twitter:card" content="summary_large_image" />
    <meta name="twitter:site" content="@HashiCorp" />
    <meta name="twitter:creator" content="@HashiCorp" />
    <meta property="og:url" content="<%= File.join(base_url, current_page.url) %>" />
    <meta property="og:title" content="<%= title_for(current_page) %>" />
    <meta property="og:site_name" content="Packer by HashiCorp"/>
    <meta property="og:image" content="<%= image_url("og-image.png") %>"/>
    <meta property="og:image:width" content="1200"/>
    <meta property="og:image:height" content="1200"/>
    <meta property="og:description" content="<%= description_for(current_page) %>" />

    <title><%= title_for(current_page) %></title>

    <!-- Stylesheets -->
    <link rel="stylesheet" href="https://use.typekit.net/wxf7mfi.css">
    <%= stylesheet_link_tag "application" %>

    <!-- Site scripts -->
    <!--[if lt IE 9]><%= javascript_include_tag "ie-compat", defer: true %><![endif]-->
    <%= javascript_include_tag "application", defer: true %>

    <!-- Analytics scrpts -->
    <script defer>
      !function(){var e=window.analytics=window.analytics||[];if(!e.initialize)if(e.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{e.invoked=!0,e.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on"],e.factory=function(t){return function(){var a=Array.prototype.slice.call(arguments);return a.unshift(t),e.push(a),e}};for(var t=0;t<e.methods.length;t++){var a=e.methods[t];e[a]=e.factory(a)}e.load=function(e){var t=document.createElement("script");t.type="text/javascript",t.async=!0,t.src=("https:"===document.location.protocol?"https://":"http://")+"cdn.segment.com/analytics.js/v1/"+e+"/analytics.min.js";var a=document.getElementsByTagName("script")[0];a.parentNode.insertBefore(t,a)},e.SNIPPET_VERSION="4.0.0",e.load("<%= segmentId %>")}}();var om597a24292a958,om597a24292a958_poll=function(){var e=0;return function(t,a){clearInterval(e),e=setInterval(t,a)}}();!function(e,t,a){if(e.getElementById(a))om597a24292a958_poll(function(){if(window.om_loaded&&!om597a24292a958)return(om597a24292a958=new OptinMonsterApp).init({s:"35109.597a24292a958",staging:0,dev:0,beta:0})},25);else{var n=!1,o=e.createElement("script");o.id=a,o.src="//a.optnmstr.com/app/js/api.min.js",o.async=!0,o.onload=o.onreadystatechange=function(){if(!(n||this.readyState&&"loaded"!==this.readyState&&"complete"!==this.readyState))try{n=om_loaded=!0,(om597a24292a958=new OptinMonsterApp).init({s:"35109.597a24292a958",staging:0,dev:0,beta:0}),o.onload=o.onreadystatechange=null}catch(e){}},(document.getElementsByTagName("head")[0]||document.documentElement).appendChild(o)}}(document,0,"omapi-script");
    </script>

    <%= yield_content :head %>
  </head>

  <body id="<%= body_id_for(current_page) %>" class="<%= body_classes_for(current_page) %>">

    <%= mega_nav :packer %>

    <div id="header" class="navigation navbar-static-top hidden-print">
      <div class="container">
        <div class="row">
          <div class="col-xs-12">
            <div class="navbar-header">
              <div class="navbar-brand">
                <a href="/">
                  <%= inline_svg "logo-text.svg", height: 50, class: "logo" %>
                </a>
              </div>
              <button class="navbar-toggle" type="button">
                <span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
              </button>
            </div>
            <div class="buttons hidden-xs">
              <nav class="navigation-links" role="navigation">
                <ul class="main-links nav navbar-nav navbar-right">
                  <li><a href="/intro/index.html">Intro</a></li>
                  <li><a href="/guides/index.html">Guides</a></li>
                  <li><a href="/docs/index.html">Docs</a></li>
                  <li><a href="/community.html">Community</a></li>
                  <li>
                    <a href="/downloads.html">
                      <%= inline_svg "download.svg" %> Download
                    </a>
                  </li>
                  <li>
                    <a href="https://github.com/hashicorp/packer">
                      <%= inline_svg "github.svg" %> GitHub
                    </a>
                  </li>
                </ul>
              </nav>
            </div>
          </div>
        </div>
      </div>
    </div>

    <%= partial "layouts/sidebar" %>

    <%= yield %>

    <div id="footer" class="navigation hidden-print">
      <div class="container">
        <div class="row">
          <div class="col-xs-12">
            <ul class="footer-links nav navbar-nav">
              <li><a href="/intro/index.html">Intro</a></li>
              <li><a href="/guides/index.html">Guides</a></li>
              <li><a href="/docs/index.html">Docs</a></li>
              <li><a href="/community.html">Community</a></li>
              <li><a href="https://www.hashicorp.com/privacy">Privacy</a></li>
              <li><a href="/security.html">Security</a></li>
              <li><a href="/assets/files/press-kit.zip">Press Kit</a></li>
            </ul>
            <ul class="footer-links nav navbar-nav navbar-right">
              <li><a href="<%= github_url :current_page %>">Edit this page</a></li>
            </ul>
          </div>
        </div>
      </div>
    </div>

    <script type="application/ld+json">
      {
        "@context": "http://schema.org",
        "@type": "Product",
        "name": "Packer",
        "alternateName": "Packer by HashiCorp",
        "manufacturer": "HashiCorp",
        "url": "https://www.packer.io",
        "logo": "<%= File.join(base_url, image_path("logo-hashicorp.svg")) %>",
        "sameAs": [
          "https://github.com/hashicorp/packer"
        ]
      }
    </script>
  </body>
</html>
